@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2004, 2005, 2008, 2010 Tama Communications Corporation
+ * Copyright (c) 2004, 2005, 2008, 2010, 2011 Tama Communications Corporation
  *
  * This file is part of GNU GLOBAL.
  *
@@ -40,6 +40,7 @@
 #endif
 
 #include "global.h"
+#include "anchor.h"
 #include "common.h"
 #include "htags.h"
 #include "path2url.h"
@@ -119,7 +120,7 @@ const char *empty_element	= "";
 const char *noframes_begin	= "<noframes>";
 const char *noframes_end	= "</noframes>";
 
-/* jquery tag */
+/* tree view tag (--tree-view) */
 const char *tree_control	= "<div id='control'>All <a href='#'>close</a> | <a href='#'>open</a></div>";
 const char *tree_begin		= "<ul id='tree'>";
 const char *tree_begin_using	= "<ul id='tree' class='%s'>";
@@ -129,6 +130,14 @@ const char *dir_end		= "";
 const char *file_begin		= "<li><span class='file'>";
 const char *file_end		= "</span></li>";
 
+/* fixed guide tag (--fixed-guide) */
+const char *guide_begin		= "<div id='guide'><ul>";
+const char *guide_end		= "</ul></div>";
+const char *guide_unit_begin	= "<li>";
+const char *guide_unit_end	= "</li>";
+const char *guide_path_begin	= "<li class='standout'><span>";
+const char *guide_path_end	= "</span></li>";
+
 /*
  * 1: Enforce XHTML1.0 strict or XHTML1.1.
  */
